==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QGraphicsItem_shell.h <==
#ifndef QGRAPHICSITEM_IMPL_SHELL_H
#define QGRAPHICSITEM_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGraphicsItem_shell : public QGraphicsItem, public QtJambiShellInterface
{
public:
    QGraphicsItem_shell(QGraphicsItem* parent0 = nullptr);
    ~QGraphicsItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsItem_access : public QGraphicsItem
{
    void __qt_addToIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_prepareGeometryChange(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_removeFromIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateMicroFocus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_advance_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint phase0);
    jobject __qt_boundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_collidesWithItem_const_QGraphicsItem_ptr_Qt_ItemSelectionMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0, jint mode1) const;
    jboolean __qt_collidesWithPath_cref_QPainterPath_Qt_ItemSelectionMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID path0, jint mode1) const;
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_extension_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject variant0) const;
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverEnterEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isObscuredBy_const_QGraphicsItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_opaqueArea(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_sceneEventFilter_QGraphicsItem_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID watched0, QtJambiNativeID event1);
    void __qt_setExtension_QGraphicsItem_Extension_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0, jobject variant1);
    jobject __qt_shape(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_supportsExtension_QGraphicsItem_Extension_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0) const;
    void __qt_wheelEvent_QGraphicsSceneWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    static inline const std::type_info& __registerEnumTypeInfo_Extension() {
        return RegistryAPI::registerEnumTypeInfo<QGraphicsItem::Extension>("QGraphicsItem::Extension", "io/qt/widgets/QGraphicsItem$Impl$Extension");
    }
};

#endif // QGRAPHICSITEM_IMPL_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QGraphicsItem_shell.h <==
#ifndef QGRAPHICSITEM_IMPL_SHELL_H
#define QGRAPHICSITEM_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGraphicsItem_shell : public QGraphicsItem, public QtJambiShellInterface
{
public:
    QGraphicsItem_shell(QGraphicsItem* parent0 = nullptr);
    ~QGraphicsItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsItem_access : public QGraphicsItem
{
    void __qt_addToIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_prepareGeometryChange(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_removeFromIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateMicroFocus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_advance_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint phase0);
    jobject __qt_boundingRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_collidesWithItem_const_QGraphicsItem_ptr_Qt_ItemSelectionMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0, jint mode1) const;
    jboolean __qt_collidesWithPath_cref_QPainterPath_Qt_ItemSelectionMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID path0, jint mode1) const;
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_extension_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject variant0) const;
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverEnterEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isObscuredBy_const_QGraphicsItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_opaqueArea_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_sceneEventFilter_QGraphicsItem_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID watched0, QtJambiNativeID event1);
    void __qt_setExtension_QGraphicsItem_Extension_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0, jobject variant1);
    jobject __qt_shape_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_supportsExtension_QGraphicsItem_Extension_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0) const;
    void __qt_wheelEvent_QGraphicsSceneWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    static inline const std::type_info& __registerEnumTypeInfo_Extension() {
        return RegistryAPI::registerEnumTypeInfo<QGraphicsItem::Extension>("QGraphicsItem::Extension", "io/qt/widgets/QGraphicsItem$Impl$Extension");
    }
};

#endif // QGRAPHICSITEM_IMPL_SHELL_H
